package poi;

import static java.nio.file.StandardOpenOption.CREATE_NEW;
import static java.nio.file.StandardOpenOption.TRUNCATE_EXISTING;
import static java.nio.file.StandardOpenOption.WRITE;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.util.Arrays;
import java.util.Optional;

import org.apache.commons.lang3.StringUtils;
import org.apache.poi.xslf.usermodel.XMLSlideShow;
import org.apache.poi.xslf.usermodel.XSLFSlide;
import org.apache.poi.xslf.usermodel.XSLFSlideLayout;

public class Bug60662 {

	public static void main(String[] args) throws IOException {
		String source = "source.pptx";
		String template = "template.pptx";
		String result = "merged.pptx";

		try (InputStream sStream = Bug60662.class.getClassLoader().getResourceAsStream(source);
				XMLSlideShow sPptx = new XMLSlideShow(sStream);
				InputStream tStream = Bug60662.class.getClassLoader().getResourceAsStream(template);
				XMLSlideShow tPptx = new XMLSlideShow(tStream);
				OutputStream rStream = Files.newOutputStream(Paths.get(result), CREATE_NEW, TRUNCATE_EXISTING, WRITE)) {

			for (XSLFSlide slide : sPptx.getSlides()) {
				String sourceLayoutName = slide.getSlideLayout().getName();
				/*
				 * Looking for layout with the same name.
				 */
				Optional<XSLFSlideLayout> templateLayout = Arrays
						.stream(tPptx.getSlideMasters().get(0).getSlideLayouts())
						.filter(sl -> StringUtils.equals(sourceLayoutName, sl.getName())).findFirst();

				/*
				 * In the case there is no layout with the same name from
				 * original side, then using defeult 'BLANK' layout.
				 */
				XSLFSlide newSlide;
				if (templateLayout.isPresent()) {
					newSlide = tPptx.createSlide(templateLayout.get());
				} else {
					newSlide = tPptx.createSlide();
				}

				/*
				 * Importing slide content.
				 */
				newSlide.importContent(slide);
			}

			tPptx.write(rStream);
			rStream.flush();
		}
	}

}
